@@ -31,6 +31,10 @@ except:
 
 try:
     from job_plugin.ec2ssh import Service as EC2Service
+except:
+    pass  
+try:
+    from job_plugin.slurmssh import Service as SlurmService
 except:
     pass 
 
@@ -40,6 +44,7 @@ except:
 import api.base
 sys.path.append(os.path.dirname(__file__))
 
+
 if SAGA_BLISS == False:
     try:
         import saga
@@ -226,18 +231,18 @@ class bigjob(api.base.bigjob):
         self.coordination.set_pilot_state(self.pilot_url, str(Unknown), False)
         self.coordination.set_pilot_description(self.pilot_url, filetransfers)    
         logger.debug("set pilot state to: " + str(Unknown))
-        
-        ##############################################################################
+
         # Create Job Service (Default: SAGA Job Service, alternative Job Services supported)
         self.js =None
         if lrms_saga_url.scheme=="gce+ssh":
-            self.js = GCEService(lrms_saga_url, pilot_compute_description)
+            self.js = GCEService(lrms_saga_url, pilot_compute_description) 
         elif lrms_saga_url.scheme=="ec2+ssh" or lrms_saga_url.scheme=="euca+ssh" \
             or lrms_saga_url.scheme=="nova+ssh":
-            self.js = EC2Service(lrms_saga_url, pilot_compute_description)
+            self.js = EC2Service(lrms_saga_url, pilot_compute_description)    
+        elif lrms_saga_url.scheme=="slurm+ssh":
+            self.js = SlurmService(lrms_saga_url, pilot_compute_description)          
         else:
-            self.js = SAGAJobService(lrms_saga_url)
-        
+            self.js = SAGAJobService(lrms_saga_url)        
         ##############################################################################
         # create job description
         jd = SAGAJobDescription()
@@ -329,6 +334,7 @@ class bigjob(api.base.bigjob):
                                                                           # or another external scheduler
                                                           )
         logger.debug("Adaptor specific modifications: "  + str(lrms_saga_url.scheme))
+
         if is_bliss and lrms_saga_url.scheme.startswith("condor")==False:
             bootstrap_script = self.__escape_bliss(bootstrap_script)
         else:
@@ -336,8 +342,9 @@ class bigjob(api.base.bigjob):
                 bootstrap_script = self.__escape_rsl(bootstrap_script)
             elif lrms_saga_url.scheme == "pbspro" or lrms_saga_url.scheme=="xt5torque" or lrms_saga_url.scheme=="torque":                
                 bootstrap_script = self.__escape_pbs(bootstrap_script)
-            elif lrms_saga_url.scheme == "ssh":
-                bootstrap_script = self.__escape_ssh(bootstrap_script)
+            elif lrms_saga_url.scheme == "ssh" and lrms_saga_url.scheme == "slurm+ssh":
+                bootstrap_script = self.__escape_ssh(bootstrap_script)                    
+                
         logger.debug(bootstrap_script)
         
         
@@ -491,7 +498,10 @@ class bigjob(api.base.bigjob):
             for i in jobs:
                 # parse job id out of sj url
                 surl = SAGAUrl(i)
-                state = self.coordination.get_job_state(surl.path)            
+                sj_id = surl.path
+                if sj_id.startswith("/"): sj_id = sj_id[1:]
+                state = str(self.coordination.get_job_state(sj_id))
+                #logger.debug("SJ: %s : State: %s"%(sj_id, str(state)))   
                 #state = job_detail["state"]                
                 if result_map.has_key(state)==False:
                     result_map[state]=1
