@@ -27,14 +27,12 @@ if __name__ == "__main__":
                              'affinity_machine_label': "", 
                              # cloud specific attributes
                              "vm_id":"ami-d7f742be",
-                             #"vm_id": "ami-7e37173b",
                              "vm_ssh_username":"ubuntu",
                              "vm_ssh_keyname":"MyKey",
                              "vm_ssh_keyfile":"/Users/luckow/.ssh/id_rsa",
                              "vm_type":"t1.micro",
-                             #"vm_region" : "us-west-1",
-                             "access_key_id":"OQTYSHQ9I6ACEXDTKTOGG",
-                             "secret_access_key":"STgYQPTyh89EWKp7lFtd77A4O2aghXjx0owqkNHm"
+                             "access_key_id":"x",
+                             "secret_access_key":"x"
                             }
     
     pilot_compute_description_amazon_west = {
@@ -50,8 +48,8 @@ if __name__ == "__main__":
                              "vm_ssh_keyfile":"/Users/luckow/.ssh/id_rsa",
                              "vm_type":"t1.micro",
                              "region" : "us-west-1",
-                             "access_key_id":"AKIAJPGNDJRYIG5LIEUA",
-                             "secret_access_key":"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"
+                             "access_key_id":"x",
+                             "secret_access_key":"x"
                            
                             }
     
